==> apeman-srch-1.1.4.tgz: package/lib/logging/srch_logger.js <==
/**
 * Logger for search.
 * @constructor SrchLogger
 * @returns A logger instance.
 */

"use strict";

const colorprint = require('colorprint'),
    textconv = require('textconv'),
    colors = colorprint.colors;

/** @lends SrchLogger */
module.exports = colorprint.define(
    /** @lends SrchLogger.prototype */
    {
        logSearchStart: function () {
            let s = this;
            s.info('Searching modules...');
        },
        logSearchDone: function () {
            let s = this;
            s.info('...search done!');
        },
        logSearched: function (serched, terms) {
            let s = this;
            s.debug('');
            if (terms.length > 0) {
                s.debug('  Terms: %s', colors.blue.italic(terms.join(', ')));
            }
            s.debug('  Searched modules:');
            s.debug('');
            let NAME_MIN_LENGTH = 24;
            serched
                .filter((searched) => {
                    return searched.hit;
                })
                .forEach((serched) => {
                    let term = serched.hitTerm;
                    let name = textconv.pad(serched.name, NAME_MIN_LENGTH);
                    let desc = serched.description;
                    if (term) {
                        name = s._highlight(name, term);
                        desc = s._highlight(desc, term);
                    }
                    s.debug("    %s%s",
                        colors.black.bold(name),
                        colors.blackBright(desc)
                    );
                });
            s.debug('');
            s.debug('');
        },
        _highlight: function (text, keyword) {
            return text.replace(new RegExp(keyword, "g"), (keyword) => {
                return colors.blue.bold(keyword);
            });
        }
    }
);

==> apeman-srch-1.1.9.tgz: package/lib/logging/srch_logger.js <==
/**
 * Logger for search.
 * @constructor SrchLogger
 * @returns A logger instance.
 */

"use strict";

const colorprint = require('colorprint'),
    textconv = require('textconv'),
    colors = colorprint.colors;

/** @lends SrchLogger */
module.exports = colorprint.define(
    /** @lends SrchLogger.prototype */
    {
        logSearchStart() {
            let s = this;
            s.info('Searching modules...');
        },
        logSearchDone() {
            let s = this;
            s.info('...search done!');
        },
        logSearched(serched, terms) {
            let s = this;
            s.debug('');
            if (terms.length > 0) {
                s.debug('  Terms: %s', colors.blue.italic(terms.join(', ')));
            }
            s.debug('  Searched modules:');
            s.debug('');
            let NAME_MIN_LENGTH = 24;
            serched
                .filter(searched => searched.hit)
                .sort((a, b) => String(a.name).localeCompare(String(b.name)))
                .forEach(serched => {
                    let term = serched.hitTerm;
                    let name = textconv.pad(serched.name, NAME_MIN_LENGTH);
                    let desc = serched.description;
                    if (term) {
                        name = s._highlight(name, term);
                        desc = s._highlight(desc, term);
                    }
                    s.debug("    %s%s",
                        colors.black.bold(name),
                        colors.blackBright(desc)
                    );
                });
            s.debug('');
            s.debug('');
        },
        _highlight(text, keyword) {
            return text && text.replace(new RegExp(keyword, "g"), (keyword) => {
                    return colors.blue.bold(keyword);
                });
        }
    }
);
